<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

class CreateBaseRbacTables extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up(): void
    {
        DB::statement('CREATE SCHEMA IF NOT EXISTS "rbac"');
        Schema::create('rbac.permissions', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->string('name')->unique();
        });
        Schema::create('rbac.roles', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->string('name')->unique();
        });
        Schema::create('rbac.roles_permissions', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->string('role_name');
            $table->string('permission_name');
            $table->foreign('role_name')->references('name')->on('rbac.roles');
            $table->foreign('permission_name')->references('name')->on('rbac.permissions');
        });
        Schema::create('rbac.roles_users', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->integer('user_id');
            $table->string('role_name');
            $table->foreign('role_name')->references('name')->on('rbac.roles');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down(): void
    {
        Schema::dropIfExists('rbac.roles_users');
        Schema::dropIfExists('rbac.roles_permissions');
        Schema::dropIfExists('rbac.roles');
        Schema::dropIfExists('rbac.permissions');
        DB::statement('DROP SCHEMA "rbac"');
    }
}
