<?php

namespace Iwaydev\Rbac\Components;

use Iwaydev\AuthorizationClient\AuthenticationClient;
use Iwaydev\BaseSender\Sender;
use GuzzleHttp\Exception\GuzzleException;
use Psr\Http\Message\ResponseInterface;

/**
 * Класс для работы с сервисом RBAC
 *
 * Class Rbac
 *
 * @package Rbac\Components
 */
class RbacClient extends Sender
{
    /**
     * Авторизация
     *
     * @param AuthenticationClient $authenticationClient
     *
     * @return $this
     */
    public function auth(AuthenticationClient $authenticationClient): self
    {
        $token = $authenticationClient->setXUuid($this->getXUuid())->caching()->tokenClientCredentials();
        $this->setHeader('Authorization', 'Bearer ' . $token);

        return $this;
    }

    /**
     * Метод получения ролей с правами доступа
     *
     * @param array $data
     *
     * @return array
     * @throws GuzzleException
     */
    public function getRoles(array $data = []): array
    {
        return $this->get('roles', $data);
    }

    /**
     * @inheritDoc
     */
    protected function prepareResponse(ResponseInterface $response): array
    {
        $response = parent::prepareResponse($response);

        return $response['data'];
    }
}