<?php

namespace Iwaydev\Rbac;

use Illuminate\Support\ServiceProvider;
use Iwaydev\AuthorizationClient\AuthenticationClient;
use Iwaydev\Rbac\Components\RbacClient;

/**
 * Провайдер RBAC
 *
 * Class RbacServiceProvider
 *
 * @package Rbac
 */
class RbacServiceProvider extends ServiceProvider
{
    public function register(): void
    {
        parent::register();

        $this->setDefaultLogChannel();

        $this->registerSender();
    }

    /**
     * Добавляет в конфиг канал для логирования, если отсутствует
     */
    protected function setDefaultLogChannel(): void
    {
        if (!config()->has('logging.channels.rbac')) {
            config()->set('logging.channels.rbac', require __DIR__ . '/../config/log-rbac.php');
        }
    }

    /**
     * Регистрирует сендер для общения с сервисов авторизации
     */
    protected function registerSender(): void
    {
        $this->app->bind(RbacClient::class, function ($app) {
            return (new RbacClient(
                config('senders.rbac.connection.url'),
                config('senders.rbac.connection.api_version'),
                cache()->store(),
                config('senders.rbac.cache.lifetime'),
                logs('rbac'),
                $app->request->header('X-UUID', null)
            ))->auth(resolve(AuthenticationClient::class));
        });
    }

    /**
     * Bootstrap the application services.
     *
     * @return void
     */
    public function boot()
    {
        if ($this->app->runningInConsole()) {
            $this->publishes([
                __DIR__ . '/../database/migrations/' => base_path('/database/migrations')
            ], 'migrations');

            $this->publishes([
                __DIR__ . '/../config/rbac.php' => config_path('senders/rbac.php'),
            ], 'config');
        }
    }
}
